aboutsummaryrefslogtreecommitdiff
path: root/gdb
diff options
context:
space:
mode:
authorAndrew Cagney <cagney@redhat.com>2000-07-18 07:47:02 +0000
committerAndrew Cagney <cagney@redhat.com>2000-07-18 07:47:02 +0000
commit7f0e3f52b0463193d131787e2cc624c8cb7133e8 (patch)
tree9fe69bd6ddee790a1de50d2901a1570a8cbbc0bd /gdb
parent7a9aaf929a34163a6939659ef61d40848f719d61 (diff)
downloadgdb-7f0e3f52b0463193d131787e2cc624c8cb7133e8.zip
gdb-7f0e3f52b0463193d131787e2cc624c8cb7133e8.tar.gz
gdb-7f0e3f52b0463193d131787e2cc624c8cb7133e8.tar.bz2
From Richard Henderson <rth@cygnus.com>:
* dwarf2read.c (dwarf2_empty_hash_tables): Renamed from dwarf2_empty_die_ref_table; zero dwarf2_cached_types as well. Update all callers.
Diffstat (limited to 'gdb')
-rw-r--r--gdb/ChangeLog6
-rw-r--r--gdb/dwarf2read.c10
2 files changed, 12 insertions, 4 deletions
diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index b181930..e7c2872 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,3 +1,9 @@
+Tue Jul 18 17:13:01 2000 Andrew Cagney <cagney@b1.cygnus.com>
+
+ From Richard Henderson <rth@cygnus.com>:
+ * dwarf2read.c (dwarf2_empty_hash_tables): Renamed from
+ dwarf2_empty_die_ref_table; zero dwarf2_cached_types as well.
+ Update all callers.
2000-07-17 Daniel Berlin <dberlin@redhat.com>
diff --git a/gdb/dwarf2read.c b/gdb/dwarf2read.c
index b331bcb..26494b4 100644
--- a/gdb/dwarf2read.c
+++ b/gdb/dwarf2read.c
@@ -729,7 +729,7 @@ void dump_die_list (struct die_info *);
void store_in_ref_table (unsigned int, struct die_info *);
-static void dwarf2_empty_die_ref_table (void);
+static void dwarf2_empty_hash_tables (void);
static unsigned int dwarf2_get_ref_die_offset (struct attribute *);
@@ -2892,8 +2892,9 @@ read_comp_unit (info_ptr, abfd)
char *cur_ptr;
int nesting_level;
- /* Reset die reference table, we are building a new one now. */
- dwarf2_empty_die_ref_table ();
+ /* Reset die reference table and cached types table; we are
+ building new ones now. */
+ dwarf2_empty_hash_tables ();
cur_ptr = info_ptr;
nesting_level = 0;
@@ -5549,9 +5550,10 @@ store_in_ref_table (offset, die)
static void
-dwarf2_empty_die_ref_table ()
+dwarf2_empty_hash_tables ()
{
memset (die_ref_table, 0, sizeof (die_ref_table));
+ memset (dwarf2_cached_types, 0, sizeof(dwarf2_cached_types));
}
static unsigned int